import trio

from sclients.types import ENR

async def connect_rumor(rumor, client, enr: ENR):
    await rumor.host.start(security='noise')

    enr_str = enr.enr_teku if client == 'teku' else enr.enr
    peer_id = await rumor.peer.connect(enr_str).peer_id()
    return peer_id



from importlib import resources
import subprocess

from sclients.types import InstanceConfig

SUPPORTED_CLIENTS = set(['prysm', 'lighthouse'])


def _start_arg_list(config: InstanceConfig):
    return [
        f'--tcp={config.enr.tcp}',
        f'--udp={config.enr.udp}',
        f'--ip={config.enr.ip}',
        f'--private-key={config.enr.private_key}',
        f'--beacon-state-path={config.beacon_state_path}',
    ]


def start_instance(instance_config: InstanceConfig, stdout=subprocess.PIPE):
    with resources.path(f'sclients.bin', f'{instance_config.client}_start') as start_path:
        output = subprocess.run(
            ['bash', start_path] + _start_arg_list(instance_config),
            stdout=stdout,
            stderr=subprocess.STDOUT,
            text=True
        )
        if output.returncode != 0:
            print(output.stdout)


def stop_instance(client: str, stdout=subprocess.PIPE):
    with resources.path(f'sclients.bin', f'{client}_stop') as stop_path:
        output = subprocess.run(
            ['bash', stop_path],
            stdout=stdout,
            stderr=subprocess.STDOUT,
            text=True
        )
        if output.returncode != 0:
            print(output.stdout)



from setuptools import setup, find_packages

with open("README.md", "rt", encoding="utf8") as f:
    readme = f.read()

setup(
    name="stethoscope-clients",
    description="Eth2 clients packaged for networking tests",
    version="0.1.4",
    long_description=readme,
    long_description_content_type="text/markdown",
    author="lsankar4033",
    author_email="lsankar4033@gmail.com",
    url="https://github.com/lsankar4033/stethoscope-clients",
    python_requires=">=3.8, <4",
    license="MIT",
    packages=find_packages(exclude=["tests"]),
    tests_require=[
        "pytest>=5.4.1,<6",
        "pytest-trio==0.6.0"
    ],
    install_requires=[
        "pyrum>=0.3.0,<0.4.0",

        # NOTE: to be consistent with pyrum's versions
        "pytest-trio==0.5.2",
        "trio==0.13.0",

        "tenacity==6.2.0"
    ],
    include_package_data=True,
    keywords=["networking", "eth2", "stethoscope"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Operating System :: OS Independent",
    ],
)
